Data handling
=============

.. automodule:: mumott.data_handling

.. index::
   single: Class reference; DataContainer

DataContainer
-------------

.. autoclass:: mumott.data_handling.DataContainer
   :members:


.. index::
   single: Class reference; InputFrame

InputFrame
----------
.. autoclass:: mumott.data_handling.input_frame.InputFrame
   :members:


.. index::
   single: Class reference; InputStack

InputStack
----------
.. autoclass:: mumott.data_handling.input_stack.InputStack
   :members:


.. index::
   single: Class reference; ReconstructionInput

ReconstructionInput
-------------------

.. autoclass:: mumott.data_handling.ReconstructionInput
   :members:
   :undoc-members:

.. index::
   single: Class reference; ReconstructionParameters

ReconstructionParameters
------------------------

.. autoclass:: mumott.data_handling.ReconstructionParameters
   :members:
   :undoc-members:


.. index::
   single: Class reference; SphericalHarmonicParameters

SphericalHarmonicParameters
---------------------------

.. autoclass:: mumott.data_handling.SphericalHarmonicParameters
   :members:
   :undoc-members:

.. index::
   single: Class reference; ReconstructionOutput

ReconstructionOutput
--------------------

.. autoclass:: mumott.data_handling.ReconstructionOutput
   :members:
   :undoc-members:

.. index::
   single: Class reference; TransformParameters

TransformParameters
-------------------

.. autoclass:: mumott.data_handling.TransformParameters
   :members:
   :undoc-members:
